Function check_sequence
pub fn check_sequence<FEN>(
executor: Executor<FEN>,
calls: &[BasicTxDetails],
sequence: Vec<usize>,
test_address: Address,
calldata: Bytes,
options: CheckSequenceOptions<'_>,
) -> Result<(bool, bool, Option<String>), Report>where
FEN: FoundryEvmNetwork,Expand description
Checks if the given call sequence breaks the invariant.
Used in shrinking phase for checking candidate sequences and in replay failures phase to test persisted failures. Returns the result of invariant check (and afterInvariant call if needed) and if sequence was entirely applied.
When options.accumulate_warp_roll is enabled, warp/roll from removed calls is folded into the
next kept call so the candidate sequence stays representable as a concrete counterexample.